@@ -37,9 +37,6 @@ import item_system
 
 from utils import _
 
-# FIXME: add --quiet depending on if not --verbose?
-RSYNC_CMD =  "rsync -a %s '%s' %s --exclude-from=/etc/cobbler/rsync.exclude --progress"
-
 def register():
    """
    The mandatory cobbler module registration hook.
@@ -87,21 +84,20 @@ class ImportSuseManager:
        return (False,None)
 
     # required function for import modules
-    def run(self,pkgdir,mirror,mirror_name,network_root=None,kickstart_file=None,rsync_flags=None,arch=None,breed=None,os_version=None):
+    def run(self,pkgdir,name,path,network_root=None,kickstart_file=None,rsync_flags=None,arch=None,breed=None,os_version=None):
         self.pkgdir = pkgdir
-        self.mirror = mirror
-        self.mirror_name = mirror_name
         self.network_root = network_root
         self.kickstart_file = kickstart_file
         self.rsync_flags = rsync_flags
         self.arch = arch
         self.breed = breed
         self.os_version = os_version
+        self.name = name
+        self.path = path
+        self.rootdir = path
 
         # some fixups for the XMLRPC interface, which does not use "None"
         if self.arch == "":           self.arch           = None
-        if self.mirror == "":         self.mirror         = None
-        if self.mirror_name == "":    self.mirror_name    = None
         if self.kickstart_file == "": self.kickstart_file = None
         if self.os_version == "":     self.os_version     = None
         if self.rsync_flags == "":    self.rsync_flags    = None
@@ -111,45 +107,6 @@ class ImportSuseManager:
         if self.breed == None:
             self.breed = "suse"
 
-        # debug log stuff for testing
-        #self.logger.info("self.pkgdir = %s" % str(self.pkgdir))
-        #self.logger.info("self.mirror = %s" % str(self.mirror))
-        #self.logger.info("self.mirror_name = %s" % str(self.mirror_name))
-        #self.logger.info("self.network_root = %s" % str(self.network_root))
-        #self.logger.info("self.kickstart_file = %s" % str(self.kickstart_file))
-        #self.logger.info("self.rsync_flags = %s" % str(self.rsync_flags))
-        #self.logger.info("self.arch = %s" % str(self.arch))
-        #self.logger.info("self.breed = %s" % str(self.breed))
-        #self.logger.info("self.os_version = %s" % str(self.os_version))
-
-        # both --import and --name are required arguments
-
-        if self.mirror is None:
-            utils.die(self.logger,"import failed.  no --path specified")
-        if self.mirror_name is None:
-            utils.die(self.logger,"import failed.  no --name specified")
-
-        # if --arch is supplied, validate it to ensure it's valid
-
-        if self.arch is not None and self.arch != "":
-            self.arch = self.arch.lower()
-            if self.arch == "x86":
-                # be consistent
-                self.arch = "i386"
-            if self.arch in [ 'i486', 'i586', 'i686' ]:
-                self.arch = "i386"
-            if self.arch not in self.get_valid_arches():
-                utils.die(self.logger,"arch must be one of: %s" % string.join(self.get_valid_arches(),", "))
-
-        # if we're going to do any copying, set where to put things
-        # and then make sure nothing is already there.
-
-        self.path = os.path.normpath( "%s/ks_mirror/%s" % (self.settings.webdir, self.mirror_name) )
-        self.rootdir = os.path.normpath( "%s/ks_mirror/%s" % (self.settings.webdir, self.mirror_name) )
-        if os.path.exists(self.path) and self.arch is None:
-            # FIXME : Raise exception even when network_root is given ?
-            utils.die(self.logger,"Something already exists at this import location (%s).  You must specify --arch to avoid potentially overwriting existing files." % self.path)
-
         # import takes a --kickstart for forcing selection that can't be used in all circumstances
 
         if self.kickstart_file and not self.breed:
@@ -161,87 +118,6 @@ class ImportSuseManager:
         if self.breed and self.breed.lower() not in self.get_valid_breeds():
             utils.die(self.logger,"Supplied import breed is not supported by this module")
 
-        # if --arch is supplied, make sure the user is not importing a path with a different
-        # arch, which would just be silly.
-
-        if self.arch:
-            # append the arch path to the name if the arch is not already
-            # found in the name.
-            for x in self.get_valid_arches():
-                if self.path.lower().find(x) != -1:
-                    if self.arch != x :
-                        utils.die(self.logger,"Architecture found on pathname (%s) does not fit the one given in command line (%s)"%(x,self.arch))
-                    break
-            else:
-                # FIXME : This is very likely removed later at get_proposed_name, and the guessed arch appended again
-                self.path += ("-%s" % self.arch)
-
-        # make the output path and mirror content but only if not specifying that a network
-        # accessible support location already exists (this is --available-as on the command line)
-
-        if self.network_root is None:
-            # we need to mirror (copy) the files
-
-            utils.mkdir(self.path)
-
-            # prevent rsync from creating the directory name twice
-            # if we are copying via rsync
-
-            if not self.mirror.endswith("/"):
-                self.mirror = "%s/" % self.mirror
-
-            if self.mirror.startswith("http://") or self.mirror.startswith("ftp://") or self.mirror.startswith("nfs://"):
-
-                # http mirrors are kind of primative.  rsync is better.
-                # that's why this isn't documented in the manpage and we don't support them.
-                # TODO: how about adding recursive FTP as an option?
-
-                utils.die(self.logger,"unsupported protocol")
-
-            else:
-
-                # good, we're going to use rsync..
-                # we don't use SSH for public mirrors and local files.
-                # presence of user@host syntax means use SSH
-
-                spacer = ""
-                if not self.mirror.startswith("rsync://") and not self.mirror.startswith("/"):
-                    spacer = ' -e "ssh" '
-                rsync_cmd = RSYNC_CMD
-                if self.rsync_flags:
-                    rsync_cmd = rsync_cmd + " " + self.rsync_flags
-
-                # kick off the rsync now
-
-                utils.run_this(rsync_cmd, (spacer, self.mirror, self.path), self.logger)
-
-        else:
-
-            # rather than mirroring, we're going to assume the path is available
-            # over http, ftp, and nfs, perhaps on an external filer.  scanning still requires
-            # --mirror is a filesystem path, but --available-as marks the network path
-
-            if not os.path.exists(self.mirror):
-                utils.die(self.logger, "path does not exist: %s" % self.mirror)
-
-            # find the filesystem part of the path, after the server bits, as each distro
-            # URL needs to be calculated relative to this.
-
-            if not self.network_root.endswith("/"):
-                self.network_root = self.network_root + "/"
-            self.path = os.path.normpath( self.mirror )
-            valid_roots = [ "nfs://", "ftp://", "http://" ]
-            for valid_root in valid_roots:
-                if self.network_root.startswith(valid_root):
-                    break
-            else:
-                utils.die(self.logger, "Network root given to --available-as must be nfs://, ftp://, or http://")
-            if self.network_root.startswith("nfs://"):
-                try:
-                    (a,b,rest) = self.network_root.split(":",3)
-                except:
-                    utils.die(self.logger, "Network root given to --available-as is missing a colon, please see the manpage example.")
-
         # now walk the filesystem looking for distributions that match certain patterns
 
         self.logger.info("adding distros")
@@ -308,7 +184,7 @@ class ImportSuseManager:
             # SELinux Apache can't symlink to NFS (without some doing)
             if not os.path.exists(dest_link):
                 try:
-                    os.symlink(base + "-" + distro.arch, dest_link)
+                    os.symlink(base, dest_link)
                 except:
                     # this shouldn't happen but I've seen it ... debug ...
                     self.logger.warning("symlink creation failed: %(base)s, %(dest)s") % { "base" : base, "dest" : dest_link }
@@ -551,7 +427,7 @@ class ImportSuseManager:
         """
 
         if self.network_root is not None:
-            name = self.mirror_name + "-".join(self.path_tail(os.path.dirname(self.path),dirname).split("/"))
+            name = self.name + "-".join(self.path_tail(os.path.dirname(self.path),dirname).split("/"))
         else:
             # remove the part that says /var/www/cobbler/ks_mirror/name
             name = "-".join(dirname.split("/")[5:])
@@ -718,6 +594,8 @@ class ImportSuseManager:
             result["x86_64"] = 1
         if result.pop("i686",False):
             result["i386"] = 1
+        if result.pop("x86",False):
+            result["i386"] = 1
         return result.keys()
 
     def match_kernelarch_file(self, filename):
