@@ -50,6 +50,7 @@ DEFAULTS = {
     "default_virt_bridge"         : "xenbr0",
     "default_virt_type"           : "auto",
     "default_virt_file_size"      : "5",
+    "default_virt_disk_driver"    : "raw",
     "default_virt_ram"            : "512",
     "default_ownership"           : [ "admin" ],
     "enable_menu"                 : 1,
@@ -85,7 +86,9 @@ DEFAULTS = {
     "power_management_default_type" : "ipmitool",
     "power_template_dir"          : "/etc/cobbler/power",
     "puppet_auto_setup"           : 0,
+    "sign_puppet_certs_automatically": 0,
     "pxe_just_once"               : 0,
+    "iso_template_dir"            : "/etc/cobbler/iso",
     "pxe_template_dir"            : "/etc/cobbler/pxe",
     "redhat_management_permissive" : 0,
     "redhat_management_type"      : "off",
